kombu.transport.memory — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.transport.memory

In-memory transport.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

- Transport
- Channel

## Transport

class `kombu.transport.memory.` `Transport`(client, **kwargs)
  class `Channel`(connection, **kwargs)
    `after_reply_message_received`(queue)
  `Transport.` `state`

    memory backend state is global.

## Channel

class `kombu.transport.memory.` `Channel`(connection, **kwargs)
  `after_reply_message_received`(queue)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »